==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/PercentageVolumeOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { PercentageVolumeOscillatorIndicatorDescription } from "./PercentageVolumeOscillatorIndicatorDescription";
/**
 * @hidden
 */
export let PercentageVolumeOscillatorIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class PercentageVolumeOscillatorIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (PercentageVolumeOscillatorIndicatorDescriptionMetadata.a == null) {
                PercentageVolumeOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PercentageVolumeOscillatorIndicatorDescriptionMetadata.c(PercentageVolumeOscillatorIndicatorDescriptionMetadata.a);
            }
            if (a.k(PercentageVolumeOscillatorIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(PercentageVolumeOscillatorIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("ShortPeriod", "Number:int");
            a.item("LongPeriod", "Number:int");
        }
        static d(a) {
            PercentageVolumeOscillatorIndicatorDescriptionMetadata.b(a);
            a.ad("PercentageVolumeOscillatorIndicator", () => new PercentageVolumeOscillatorIndicatorDescription());
            a.ac("PercentageVolumeOscillatorIndicator", PercentageVolumeOscillatorIndicatorDescriptionMetadata.a);
        }
    }
    PercentageVolumeOscillatorIndicatorDescriptionMetadata.$t = markType(PercentageVolumeOscillatorIndicatorDescriptionMetadata, 'PercentageVolumeOscillatorIndicatorDescriptionMetadata');
    PercentageVolumeOscillatorIndicatorDescriptionMetadata.a = null;
    return PercentageVolumeOscillatorIndicatorDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/PercentageVolumeOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { PercentageVolumeOscillatorIndicatorDescription } from "./PercentageVolumeOscillatorIndicatorDescription";
/**
 * @hidden
 */
export let PercentageVolumeOscillatorIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class PercentageVolumeOscillatorIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (PercentageVolumeOscillatorIndicatorDescriptionMetadata.a == null) {
                PercentageVolumeOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PercentageVolumeOscillatorIndicatorDescriptionMetadata.c(PercentageVolumeOscillatorIndicatorDescriptionMetadata.a);
            }
            if (a.k(PercentageVolumeOscillatorIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(PercentageVolumeOscillatorIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("ShortPeriod", "Number:int");
            a.item("LongPeriod", "Number:int");
        }
        static d(a) {
            PercentageVolumeOscillatorIndicatorDescriptionMetadata.b(a);
            a.ae("PercentageVolumeOscillatorIndicator", () => new PercentageVolumeOscillatorIndicatorDescription());
            a.ad("PercentageVolumeOscillatorIndicator", PercentageVolumeOscillatorIndicatorDescriptionMetadata.a);
        }
    }
    PercentageVolumeOscillatorIndicatorDescriptionMetadata.$t = markType(PercentageVolumeOscillatorIndicatorDescriptionMetadata, 'PercentageVolumeOscillatorIndicatorDescriptionMetadata');
    PercentageVolumeOscillatorIndicatorDescriptionMetadata.a = null;
    return PercentageVolumeOscillatorIndicatorDescriptionMetadata;
})();
